@@ -3,6 +3,7 @@ from smartystreets_python_sdk.us_street import Client as USStreetClient
 from smartystreets_python_sdk.us_zipcode import Client as USZIPClient
 from smartystreets_python_sdk.us_extract import Client as USExtractClient
 from smartystreets_python_sdk.us_autocomplete import Client as USAutocompleteClient
+from smartystreets_python_sdk.us_reverse_geo import Client as USReverseGeoClient
 from smartystreets_python_sdk.international_street import Client as InternationalStreetClient
 
 
@@ -22,11 +23,13 @@ class ClientBuilder:
         self.proxy = None
         self.debug = None
         self.header = None
+        self.licenses = []
         self.INTERNATIONAL_STREET_API_URL = "https://international-street.api.smartystreets.com/verify"
         self.US_AUTOCOMPLETE_API_URL = "https://us-autocomplete.api.smartystreets.com/suggest"
         self.US_EXTRACT_API_URL = "https://us-extract.api.smartystreets.com"
         self.US_STREET_API_URL = "https://us-street.api.smartystreets.com/street-address"
         self.US_ZIP_CODE_API_URL = "https://us-zipcode.api.smartystreets.com/lookup"
+        self.US_REVERSE_GEO_API_URL =  "https://us-reverse-geo.api.smartystreets.com/lookup"
 
     def retry_at_most(self, max_retries):
         """
@@ -104,6 +107,15 @@ class ClientBuilder:
         self.debug = True
         return self
 
+    def with_licenses(self, licenses):
+        """
+        Allows the caller to specify the subscription license (aka "track") they wish to use.
+        :param licenses: Input licenses
+        :return: Returns self to accommodate method chaining
+        """
+        self.licenses.extend(licenses)
+        return self
+
     def build_international_street_api_client(self):
         self.ensure_url_prefix_not_null(self.INTERNATIONAL_STREET_API_URL)
         return InternationalStreetClient(self.build_sender(), self.serializer)
@@ -124,6 +136,10 @@ class ClientBuilder:
         self.ensure_url_prefix_not_null(self.US_ZIP_CODE_API_URL)
         return USZIPClient(self.build_sender(), self.serializer)
 
+    def build_us_reverse_geo_api_client(self):
+        self.ensure_url_prefix_not_null(self.US_REVERSE_GEO_API_URL)
+        return USReverseGeoClient(self.build_sender(), self.serializer)
+
     def build_sender(self):
         if self.http_sender is not None:
             return self.http_sender
@@ -144,6 +160,8 @@ class ClientBuilder:
 
         sender = smarty.URLPrefixSender(self.url_prefix, sender)
 
+        sender = smarty.LicenseSender(self.licenses, sender)
+
         return sender
 
     def ensure_url_prefix_not_null(self, url):
