@@ -1,3 +1,5 @@
+from .changes import Changes
+
 class Analysis:
     def __init__(self, obj):
         """
@@ -6,3 +8,4 @@ class Analysis:
         self.verification_status = obj.get('verification_status')
         self.address_precision = obj.get('address_precision')
         self.max_address_precision = obj.get('max_address_precision')
+        self.changes = Changes(obj.get("changes", {}))
